AFTAttention class
Constructors
- AFTAttention(int embedSize, int headSize, int maxSeqLen, {bool masked = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyLayer → Layer
-
final
- masked → bool
-
final
- posBias → Tensor
-
final
- queryLayer → Layer
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueLayer → Layer
-
final
Methods
-
forward(
Tensor x, List< Tensor> tracker, {Tensor? kv}) → Tensor -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parameters(
) → List< Tensor> -
override
-
step(
double lr) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited