MultiHeadAFT class

Inheritance

Constructors

MultiHeadAFT(int numHeads, int embedSize, int maxSeqLen, {bool masked = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
heads List<AFTAttention>
final
headSize int
final
masked bool
final
numHeads int
final
proj Layer
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forward(Tensor x, List<Tensor> tracker) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited