TextDecoderBlock class
Constructors
- TextDecoderBlock(int embedSize, int numHeads, int blockSize)
Properties
- crossAttention → AFTAttention
-
final
- ff1 → Layer
-
final
- ff2 → Layer
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- norm1 → LayerNorm
-
final
- norm2 → LayerNorm
-
final
- norm3 → LayerNorm
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfAttention → AFTAttention
-
final
Methods
-
forward(
Tensor x, Tensor encoderOutput, List< Tensor> tracker) → Tensor -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parameters(
) → List< Tensor> -
override
-
step(
double lr) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited