TransformerDecoder class

Inheritance

Constructors

TransformerDecoder({int vocabSize = 4098, int embedSize = 128, int blockSize = 16, int numLayers = 4, int numHeads = 4, int encoderEmbedSize = 128})

Properties

blocks List<TransformerDecoderBlock>
final
blockSize int
final
embedSize int
final
encoderEmbedSize int
final
finalLayerNorm LayerNorm
final
hashCode int
The hash code for this object.
no setterinherited
lmHead Layer
final
numHeads int
final
numLayers int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vocabSize int
final
wpe Tensor
final
wte Tensor
final

Methods

forward(List<int> idx, Tensor encoderOutput, List<Tensor> tracker) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited