TransformerDecoderBlock class

Inheritance

Constructors

TransformerDecoderBlock(int embedSize, int numHeads, int encoderEmbedSize, int maxSeqLen)

Properties

crossAttention MultiHeadAFTCross
final
embedSize int
final
ffn FeedForward
final
hashCode int
The hash code for this object.
no setterinherited
ln1 LayerNorm
final
ln2 LayerNorm
final
ln3 LayerNorm
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfAttention MultiHeadAFT
final

Methods

forward(Tensor xDec, Tensor xEnc, List<Tensor> tracker) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited