TransformerEncoderBlock class

Inheritance

Constructors

TransformerEncoderBlock(int embedSize, int numHeads, int maxSeqLen)

Properties

attention MultiHeadAFT
final
embedSize int
final
ffn Layer
final
hashCode int
The hash code for this object.
no setterinherited
ln1 LayerNorm
final
ln2 LayerNorm
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forward(Tensor x, List<Tensor> tracker) Tensor
x: T, embedSize
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited