TripletLoader class

Constructors

TripletLoader(String rootPath, int imageSize)

Properties

hashCode int
The hash code for this object.
no setterinherited
imageSize int
final
rootPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

nextBatch(int batchSize) Map<String, Tensor>
Loads a batch of batchSize triplets directly into GPU memory
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited