AudioTransformer class

Inheritance

Constructors

AudioTransformer({required int featureDim, required int maxSequenceLength, required int embedSize, required int numClasses, int numLayers = 4, int numHeads = 4})

Properties

classificationHead Layer
getter/setter pair
embedSize int
final
featureDim int
final
featureProjection Layer
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxSequenceLength int
final
numClasses int
final
posEmbeddings Tensor
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transformerEncoder TransformerEncoder
final

Methods

forward(Tensor audioFeatures, List<Tensor> tracker) Tensor
Takes input actualSequenceLength, featureDim
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited