Mcts class

Constructors

Mcts(Game game, TransformerDecoder gpt)

Properties

bigSize int
final
blockSize int
final
dummyEnc Tensor
final
game → Game
final
gpt TransformerDecoder
final
hashCode int
The hash code for this object.
no setterinherited
rootNode Node
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vocabSize int
final

Methods

monteCarlo({int maxIterations = 5000, int timeLimit = 5000}) Future<EngineResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited