Tensor class

Constructors

Tensor(List<int> shape, List<double> data)
Tensor.fromFloatList(Pointer<Float> matrix, int rows, int cols)
factory

Properties

data Float32List
getter/setter pair
grad Float32List
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape List<int>
getter/setter pair

Methods

matMul(Tensor other) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printMatrix() String
Helper function to print a matrix from a flat array.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited