MultimodalTransformer class

Inheritance

Constructors

MultimodalTransformer({required AudioTransformer audioModel, required VideoTransformer videoModel, required int numClasses})

Properties

audioModel AudioTransformer
final
fusionHead Layer
final
hashCode int
The hash code for this object.
no setterinherited
numClasses int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoModel VideoTransformer
final

Methods

forward(Tensor audioIn, Tensor videoIn, List<Tensor> tracker) Tensor
Forward pass performing 'Intermediate Fusion' on GPU
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited