MultimodalTransformer class

Inheritance

Constructors

MultimodalTransformer({required AudioTransformer audioEncoder, required VideoTransformer videoEncoder, required TextTransformer textEncoder, required int jointEmbedSize, int fusionLayers = 2, int fusionHeads = 4, int maxTotalSeqLen = 200})

Properties

audioEncoder AudioTransformer
final
fusionEncoder TransformerEncoder
final
hashCode int
The hash code for this object.
no setterinherited
jointEmbedSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textEncoder TextTransformer
final
videoEncoder VideoTransformer
final

Methods

forward(Tensor audio, Tensor video, List<int> inputTextTokens, List<Tensor> tracker) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited