Layer class

Inheritance

Constructors

Layer(int nin, int nout, {required bool useGelu})

Properties

b Tensor
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useGelu bool
final
w Tensor
getter/setter pair

Methods

forward(Tensor x, List<Tensor> tracker) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited