Module class abstract
- Implementers
- AFTAttention
- AFTCrossAttention
- AudioTransformer
- FeedForward
- Layer
- LayerNorm
- MLP
- MultiHeadAFT
- MultiHeadAFTCross
- MultimodalTransformer
- MultimodalTransformer
- MultimodalTransformer
- TextDecoder
- TextDecoderBlock
- TextTransformer
- TransformerDecoder
- TransformerDecoder
- TransformerDecoderBlock
- TransformerEncoder
- TransformerEncoderBlock
- TripletLossGPU
- VideoTransformer
- ViTBackbone
- ViTFaceEmbeddingGPU
- ViTObjectDetector
Constructors
- Module()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parameters(
) → List< Tensor> -
step(
double lr) → void -
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited