TextDecoder class

Inheritance

Constructors

TextDecoder({required int vocabSize, required int maxSeqLen, required int embedSize, int numLayers = 4, int numHeads = 4})

Properties

blocks List<TextDecoderBlock>
final
embedSize int
final
finalLayerNorm LayerNorm
final
hashCode int
The hash code for this object.
no setterinherited
lmHead Layer
final
maxSeqLen int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vocabSize int
final
wpe Tensor
final
wte Tensor
final

Methods

forward(List<int> textTokens, Tensor encoderOutput, List<Tensor> tracker) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited