TextTransformer class

Inheritance

Constructors

TextTransformer({required int vocabSize, required int maxSeqLen, required int embedSize, int numLayers = 4, int numHeads = 4})

Properties

embedSize int
final
encoder TransformerEncoder
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forward(List<int> tokens, List<Tensor> tracker) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited