VideoTransformer class

Inheritance

Constructors

VideoTransformer({required int frameEmbedDim, required int embedSize, required int maxVideoSequenceLength, required int numClasses, int numLayers = 2, int numHeads = 4})

Properties

embedSize int
final
frameEmbedDim int
final
frameProjection Layer?
final
hashCode int
The hash code for this object.
no setterinherited
maxVideoSequenceLength int
final
mlpHead Layer
final
numClasses int
final
posEmbeddings Tensor
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transformerEncoder TransformerEncoder
final

Methods

forward(Tensor videoEmbeddings, List<Tensor> tracker) Tensor
Forward pass on the GPU
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited