ViTObjectDetector class

Inheritance

Constructors

ViTObjectDetector({required int imageSize, required int patchSize, required int numChannels, required int embedSize, required int numLayers, required int numHeads, required int numClasses, required int numQueries})

Properties

backbone ViTBackbone
final
boxHead Layer
getter/setter pair
classHead Layer
getter/setter pair
embedSize int
final
hashCode int
The hash code for this object.
no setterinherited
numClasses int
final
numQueries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forward(Tensor patchifiedImage, List<Tensor> tracker) Map<String, Tensor>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
step(double lr) → void
inherited
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited