Adam class
Constructors
Properties
- beta1 → double
-
final
- beta2 → double
-
final
- eps → double
-
final
- gradClip → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lr → double
-
final
-
m
→ List<
Tensor> -
final
-
params
→ List<
Tensor> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- t ↔ int
-
getter/setter pair
-
tracker
→ List<
Tensor> -
final
-
v
→ List<
Tensor> -
final
Methods
-
dispose(
) → void - Vital: Manually free GPU memory for moment buffers
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
step(
) → void - Performs the parameter update.
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void - Wipes gradients on the GPU. Called before every backward pass.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited