ViTFaceEmbeddingGPU class
Constructors
Properties
- backbone → ViTBackbone
-
final
- finalProjection ↔ Layer?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFaceEmbedding(
Tensor patchifiedImage, List< Tensor> tracker) → Tensor -
Input:
numPatches, patchPixelsOutput:1, outputDimL2-normalized vector Input:numPatches, patchPixelsOutput:1, outputDimL2-normalized vector -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parameters(
) → List< Tensor> -
override
-
step(
double lr) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited