UciEngine class
Constructors
Properties
- game ↔ Game
-
getter/setter pair
- gpt ↔ TransformerDecoder
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSearching ↔ bool
-
getter/setter pair
- mcts ↔ Mcts?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleCommand(
String command) → void -
handleGo(
List< String> parts) → void -
handlePosition(
List< String> parts) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startLoop(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited