Conv2d class
Constructors
Properties
- bias ↔ Tensor
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inChannels → int
-
final
- kernelSize → int
-
final
- outChannels → int
-
final
- padding → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stride → int
-
final
- weight ↔ Tensor
-
getter/setter pair
Methods
-
dispose(
) → void -
forward(
Tensor input, List< Tensor> tracker) → Tensor -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parameters(
) → List< Tensor> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited